@@ -11,6 +11,9 @@ import Data.List (intersperse)
 import Text.Printf (printf)
 import Text.JSON
 import qualified Data.ByteString.Char8 as B
+import qualified RestyScript.Emitter.RestyScript as RS
+
+infixr 6 <+>
 
 data VarType = VTLiteral
              | VTSymbol
@@ -48,6 +51,9 @@ bs = B.pack
 (~~) = B.append
 (<+>) = merge
 
+joinStr :: B.ByteString -> [B.ByteString] -> B.ByteString
+joinStr sep ls = B.intercalate sep ls
+
 emit :: RSVal -> [Fragment]
 emit node =
     case node of
@@ -83,6 +89,7 @@ emit node =
         Where cond -> str "where " <+> emit cond
         OrderBy pairs -> str "order by " <+> emitForList pairs
         Symbol name -> str $ bs $ quoteIdent name
+        Type name -> str $ bs name
         Keyword s -> str $ bs $ s
 
         GroupBy (Variable _ v) -> [FString $ "group by ", FVariable v VTSymbol]
@@ -128,7 +135,7 @@ emit node =
         RSTrue -> str "true"
         RSFalse -> str "false"
         HttpCmd _ _ _ -> []  -- this shouldn't happen
-
+        Capture _ -> str $ RS.emit node
     where emitForList ls = join ", " $ map emit ls
 
 str :: B.ByteString -> [Fragment]
